dist_x: Estimated cumulative distribution function for the true...

View source: R/dist.R

dist_xR Documentation

Estimated cumulative distribution function for the true variable(s)

Description

Estimated cumulative distribution function for the true variable(s)

Usage

dist_x(obj, vals, expand = FALSE)

Arguments

obj

A bdeconv_result object.

vals

A numeric vector (for univariate) or matrix (for multivariate) on which to evaluate the CDF.

expand

Used only for mv_res objects. A logical value indicating whether or not to expand the matrix of values.

Value

A numeric matrix or array of cumulative distribution values for which each row represents the estimated CDF corresponding to each MCMC iteration.


BayesDecon documentation built on March 15, 2026, 1:06 a.m.