mean.bdeconv_result: Computing mean of MCMC samples

View source: R/mean.R

mean.bdeconv_resultR Documentation

Computing mean of MCMC samples

Description

Computing mean of MCMC samples

Usage

## S3 method for class 'bdeconv_result'
mean(x, ...)

Arguments

x

A bdeconv_result object.

...

Unused.

Details

Where a direct point-wise mean is not appropriate (i.e. for mixture density results), mixtures are expanded to included every component from every sampled density with weights divided by n, the number of samples from which the mean is being taken.

Value

A bdeconv_result object with one sample constituting the mean


BayesDecon documentation built on March 15, 2026, 1:06 a.m.