plot.bdeconv_result: Visualization of 'bdeconv_result' object

View source: R/plot.R

plot.bdeconv_resultR Documentation

Visualization of bdeconv_result object

Description

Visualization of bdeconv_result object

Usage

## S3 method for class 'bdeconv_result'
plot(x, ..., use_ggplot = TRUE)

Arguments

x

A bdeconv_result object.

...

Unused.

use_ggplot

A logical value indicating whether the plots will be generated using ggplot2 or using base plot functions.

Details

By default it uses ggplot2 package if it is available in the system library, otherwise it falls back to the base R plot function.

Value

A collection of plots illustrating various densities and related functions.


BayesDecon documentation built on March 15, 2026, 1:06 a.m.