print.bdeconv_result: Printing summary of MCMC samples for 'bdeconv_result' object

View source: R/print.R

print.bdeconv_resultR Documentation

Printing summary of MCMC samples for bdeconv_result object

Description

Printing summary of MCMC samples for bdeconv_result object

Usage

## S3 method for class 'bdeconv_result'
print(x, ...)

Arguments

x

A bdeconv_result object.

...

Unused.

Details

For episodic components, this gives five number summary for the observed surrogates (y), the latent surrogates corresponding to the consumption days (w), the true intake patterns (x) and the errors (u). For regular components, this gives five number summary for y, x and u only.

Value

Prints the five number summary for the relevant variables.


BayesDecon documentation built on March 15, 2026, 1:06 a.m.