| dens_x | R Documentation |
Estimated density function for the true variable(s)
dens_x(obj, vals, expand = FALSE)
obj |
A |
vals |
A numeric vector (for univariate) or matrix (for multivariate) on which to evaluate the density. |
expand |
Used only for |
A numeric matrix or array of density values for which each row represents the estimated density corresponding to each MCMC iteration.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.