Learn R Programming

BayesDecon (version 0.1.4)

dens_x: Estimated density function for the true variable(s)

Description

Estimated density function for the true variable(s)

Usage

dens_x(obj, vals, expand = FALSE)

Value

A numeric matrix or array of density values for which each row represents the estimated density corresponding to each MCMC iteration.

Arguments

obj

A bdeconv_result object.

vals

A numeric vector (for univariate) or matrix (for multivariate) on which to evaluate the density.

expand

Used only for mv_res objects. A logical value indicating whether or not to expand the matrix of values.