Estimated density function for the true variable(s)
dens_x(obj, vals, expand = FALSE)A numeric matrix or array of density values for which each row represents the estimated density corresponding to each MCMC iteration.
A bdeconv_result object.
A numeric vector (for univariate) or matrix (for multivariate) on which to evaluate the density.
Used only for mv_res objects. A logical value indicating
whether or not to expand the matrix of values.