| dist_x | R Documentation |
Estimated cumulative distribution function for the true variable(s)
dist_x(obj, vals, expand = FALSE)
obj |
A |
vals |
A numeric vector (for univariate) or matrix (for multivariate) on which to evaluate the CDF. |
expand |
Used only for |
A numeric matrix or array of cumulative distribution values for which each row represents the estimated CDF corresponding to each MCMC iteration.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.