Learn R Programming

BayesDecon (version 0.1.4)

mean.bdeconv_result: Computing mean of MCMC samples

Description

Computing mean of MCMC samples

Usage

# S3 method for bdeconv_result
mean(x, ...)

Value

A bdeconv_result object with one sample constituting the mean

Arguments

x

A bdeconv_result object.

...

Unused.

Details

Where a direct point-wise mean is not appropriate (i.e. for mixture density results), mixtures are expanded to included every component from every sampled density with weights divided by n, the number of samples from which the mean is being taken.