| plot.bdeconv_result | R Documentation |
bdeconv_result objectVisualization of bdeconv_result object
## S3 method for class 'bdeconv_result'
plot(x, ..., use_ggplot = TRUE)
x |
A |
... |
Unused. |
use_ggplot |
A logical value indicating whether the plots will be generated using |
By default it uses ggplot2 package if it is available in the system library, otherwise it falls back to the base R plot function.
A collection of plots illustrating various densities and related functions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.