| print.bdeconv_result | R Documentation |
bdeconv_result objectPrinting summary of MCMC samples for bdeconv_result object
## S3 method for class 'bdeconv_result'
print(x, ...)
x |
A |
... |
Unused. |
For episodic components, this gives five number summary for the observed surrogates (y), the latent surrogates corresponding to the consumption days (w), the true intake patterns (x) and the errors (u). For regular components, this gives five number summary for y, x and u only.
Prints the five number summary for the relevant variables.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.