Learn R Programming

BayesDecon (version 0.1.4)

print.bdeconv_result: Printing summary of MCMC samples for bdeconv_result object

Description

Printing summary of MCMC samples for bdeconv_result object

Usage

# S3 method for bdeconv_result
print(x, ...)

Value

Prints the five number summary for the relevant variables.

Arguments

x

A bdeconv_result object.

...

Unused.

Details

For episodic components, this gives five number summary for the observed surrogates (y), the latent surrogates corresponding to the consumption days (w), the true intake patterns (x) and the errors (u). For regular components, this gives five number summary for y, x and u only.