bdeconv_result objectPrinting summary of MCMC samples for bdeconv_result object
# S3 method for bdeconv_result
print(x, ...)Prints the five number summary for the relevant variables.
A bdeconv_result object.
Unused.
For episodic components, this gives five number summary for the observed surrogates (y), the latent surrogates corresponding to the consumption days (w), the true intake patterns (x) and the errors (u). For regular components, this gives five number summary for y, x and u only.