| RTCNormal | R Documentation |
Density and distribution functions for the mean-restricted two-component normal distribution.
drtcnorm(x, p, mu, sig1, sig2, log = FALSE)
prtcnorm(q, p, mu, sig1, sig2, lower.tail = TRUE, log.p = FALSE)
x |
A vector of quantiles. |
p |
A scalar mixture weight. |
mu |
A scalar separation parameter. |
sig1 |
A scalar standard deviation for the first component. |
sig2 |
A scalar standard deviation for the second component. |
log |
A logical value indication whether a probability |
lower.tail |
A logical value indicated whether or not to take the cumulative distribution function with respect to the lower tail (alternatively upper). |
drtcnorm gives the density, prtcnorm gives the distribution.
The length of the result is determined by the length of x for drtcnorm.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.